﻿using System.Windows;
using System.Windows.Forms;
using System.Windows.Interop;
using TETCSharpClient;
using TETControls.Calibration;
using MessageBox = System.Windows.MessageBox;
using Size = System.Drawing.Size;

namespace SimpleCalibrator
{
    public partial class MainWindow : Window
    {
        private Screen screen;
        private Size area;
        private int numPoints = 9;

        public MainWindow()
        {
            GazeManager.Instance.Activate(GazeManager.ApiVersion.VERSION_1_0, GazeManager.ClientMode.Push);

            InitializeComponent();

            if (!GazeManager.Instance.IsConnected)
            {
                MessageBox.Show("EyeTribe Server has not been started");
                Close();
            }

            Calibrate();
            GazeManager.Instance.Deactivate();
            Close();
        }

        private void Calibrate()
        {
            //Run the calibration on 'this' monitor, default to full screen nine points
            screen = Screen.FromHandle(new WindowInteropHelper(this).Handle);
            area = new Size(screen.Bounds.Width, screen.Bounds.Height);

            ParseArguments();

            // Run the calibration
            CalibrationRunner calRunner = new CalibrationRunner(screen, area, numPoints);
            calRunner.Start();
        }

        private void ParseArguments()
        {
            foreach (string s in App.args)
            {
                if (string.IsNullOrEmpty(s))
                    continue;

                string[] keyVal = s.Split('=');

                if (keyVal.Length < 2)
                    continue;

                string keyStr = keyVal[0];
                string valueStr = keyVal[1];

                int value = 0;
                int.TryParse(valueStr, out value);

                if(string.IsNullOrEmpty(keyStr) || value == 0)
                    continue;

                switch (keyStr)
                {
                    case "width":
                        if(value < screen.Bounds.Width)
                           area.Width = value;
                        break;

                    case "height":
                        if(value < screen.Bounds.Height)
                           area.Height = value;
                        break;

                    case "numpoints":
                        if(value == 9 || value == 12 || value == 16)
                        numPoints = value;
                        break;
                }
            }
        }
    }
}
